==> jc-1.4.0.tar.gz: java/text/CollationKey.h <==
// public final class java.text.CollationKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 10fbf4bbc57e726f java_text_CollationKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_CollationKey_H_
#define _JC_java_text_CollationKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_CollationKey$object;
struct _jc_java_text_Collator$object;

// Typedefs
typedef struct _jc_java_text_CollationKey$sub_refs	_jc_java_text_CollationKey$sub_refs;
typedef struct _jc_java_text_CollationKey$sub_nonrefs	_jc_java_text_CollationKey$sub_nonrefs;
typedef struct _jc_java_text_CollationKey$refs	_jc_java_text_CollationKey$refs;
typedef struct _jc_java_text_CollationKey$nonrefs	_jc_java_text_CollationKey$nonrefs;
typedef struct _jc_java_text_CollationKey$object	_jc_java_text_CollationKey$object;

typedef const struct _jc_java_text_CollationKey$vmethods	_jc_java_text_CollationKey$vmethods;
typedef const struct _jc_java_text_CollationKey$vtable	_jc_java_text_CollationKey$vtable;
typedef const struct _jc_java_text_CollationKey$vtype	_jc_java_text_CollationKey$vtype;

// Constructors
extern void _jc_java_text_CollationKey$method$_init$91c57c0b13ea839f(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_text_Collator$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *);

// Virtual methods
extern jint _jc_java_text_CollationKey$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_text_CollationKey$method$compareTo$bfa6b0ea93433fb2(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_text_CollationKey$object *);
extern jboolean _jc_java_text_CollationKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_text_CollationKey$method$getSourceString$7deb5998ebffcf43(_jc_env *, struct _jc_java_text_CollationKey$object *);
extern jint _jc_java_text_CollationKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_text_CollationKey$object *);
extern _jc_byte_array *_jc_java_text_CollationKey$method$toByteArray$3292ac9bfdd8d59a(_jc_env *, struct _jc_java_text_CollationKey$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_CollationKey$method_info$compareTo$84fc6fc4a23c98a3;
extern _jc_method _jc_java_text_CollationKey$method_info$compareTo$bfa6b0ea93433fb2;
extern _jc_method _jc_java_text_CollationKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_text_CollationKey$method_info$getSourceString$7deb5998ebffcf43;
extern _jc_method _jc_java_text_CollationKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_text_CollationKey$method_info$toByteArray$3292ac9bfdd8d59a;

// Virtual methods structure
struct _jc_java_text_CollationKey$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*compareTo$bfa6b0ea93433fb2)(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_text_CollationKey$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getSourceString$7deb5998ebffcf43)(_jc_env *, struct _jc_java_text_CollationKey$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_text_CollationKey$object *);
	_jc_byte_array	*(*toByteArray$3292ac9bfdd8d59a)(_jc_env *, struct _jc_java_text_CollationKey$object *);
};

// Vtable
struct _jc_java_text_CollationKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_CollationKey$vmethods	java_text_CollationKey;
};

// Vtype
struct _jc_java_text_CollationKey$vtype {
	_jc_type			type;
	_jc_java_text_CollationKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_CollationKey$sub_refs {
	struct _jc_java_text_Collator$object	*collator;
	struct _jc_java_lang_String$object	*originalText;
	_jc_byte_array	*key;
};

// Reference instance fields (object)
struct _jc_java_text_CollationKey$refs {
    _jc_java_text_CollationKey$sub_refs	java_text_CollationKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_CollationKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_CollationKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_CollationKey$sub_nonrefs	java_text_CollationKey;
};

// Object instance structure
struct _jc_java_text_CollationKey$object {
	_jc_java_text_CollationKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_CollationKey$vtype	*vtype;
	_jc_java_text_CollationKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_CollationKey$vtype _jc_java_text_CollationKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_CollationKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_CollationKey$class_object;

#endif	/* _JC_java_text_CollationKey_H_ */

==> jc-1.4.6.tar.gz: java/text/CollationKey.h <==
// public final class java.text.CollationKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 10fbf4bbc57e726f java_text_CollationKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_CollationKey_H_
#define _JC_java_text_CollationKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_CollationKey$object;
struct _jc_java_text_Collator$object;

// Typedefs
typedef struct _jc_java_text_CollationKey$sub_refs	_jc_java_text_CollationKey$sub_refs;
typedef struct _jc_java_text_CollationKey$sub_nonrefs	_jc_java_text_CollationKey$sub_nonrefs;
typedef struct _jc_java_text_CollationKey$refs	_jc_java_text_CollationKey$refs;
typedef struct _jc_java_text_CollationKey$nonrefs	_jc_java_text_CollationKey$nonrefs;
typedef struct _jc_java_text_CollationKey$object	_jc_java_text_CollationKey$object;

typedef const struct _jc_java_text_CollationKey$vmethods	_jc_java_text_CollationKey$vmethods;
typedef const struct _jc_java_text_CollationKey$vtable	_jc_java_text_CollationKey$vtable;
typedef const struct _jc_java_text_CollationKey$vtype	_jc_java_text_CollationKey$vtype;

// Constructors
extern void _jc_java_text_CollationKey$method$_init$91c57c0b13ea839f(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_text_Collator$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_text_CollationKey$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_CollationKey$method$compareTo$bfa6b0ea93433fb2(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_text_CollationKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_text_CollationKey$method$getSourceString$7deb5998ebffcf43(_jc_env *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_CollationKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_text_CollationKey$method$toByteArray$3292ac9bfdd8d59a(_jc_env *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_CollationKey$method_info$compareTo$84fc6fc4a23c98a3;
extern _jc_method _jc_java_text_CollationKey$method_info$compareTo$bfa6b0ea93433fb2;
extern _jc_method _jc_java_text_CollationKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_text_CollationKey$method_info$getSourceString$7deb5998ebffcf43;
extern _jc_method _jc_java_text_CollationKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_text_CollationKey$method_info$toByteArray$3292ac9bfdd8d59a;

// Virtual methods structure
struct _jc_java_text_CollationKey$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*compareTo$bfa6b0ea93433fb2)(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_text_CollationKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSourceString$7deb5998ebffcf43)(_jc_env *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*toByteArray$3292ac9bfdd8d59a)(_jc_env *, struct _jc_java_text_CollationKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_CollationKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_CollationKey$vmethods	java_text_CollationKey;
};

// Vtype
struct _jc_java_text_CollationKey$vtype {
	_jc_type			type;
	_jc_java_text_CollationKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_CollationKey$sub_refs {
	struct _jc_java_text_Collator$object	*collator;
	struct _jc_java_lang_String$object	*originalText;
	_jc_byte_array	*key;
};

// Reference instance fields (object)
struct _jc_java_text_CollationKey$refs {
    _jc_java_text_CollationKey$sub_refs	java_text_CollationKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_CollationKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_CollationKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_CollationKey$sub_nonrefs	java_text_CollationKey;
};

// Object instance structure
struct _jc_java_text_CollationKey$object {
	_jc_java_text_CollationKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_CollationKey$vtype	*vtype;
	_jc_java_text_CollationKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_CollationKey$vtype _jc_java_text_CollationKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_CollationKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_CollationKey$class_object;

#endif	/* _JC_java_text_CollationKey_H_ */
